package App::Session::Token;

our $VERSION = '0.100';

1;



__END__

=encoding utf-8

=head1 NAME

App::Session::Token - Command line interface to Session::Token

=head1 DESCRIPTION

This interface is described in the L<session-token> documentation.

=head1 SEE ALSO

L<App-Session-Token github repo|https://github.com/hoytech/App-Session-Token>

L<Session::Token>

=head1 AUTHOR

Doug Hoyte, C<< <doug@hcsw.org> >>

=head1 COPYRIGHT & LICENSE

Copyright 2014 Doug Hoyte.

This module is licensed under the same terms as perl itself.
